pub struct Item {
pub item_sequence_number: String,
pub amazon_product_identifier: Option<String>,
pub vendor_product_identifier: Option<String>,
pub shipped_quantity: Box<ItemQuantity>,
pub item_details: Option<Box<ItemDetails>>,
}Expand description
Item : Details of the item being shipped.
Fields
item_sequence_number: StringItem sequence number for the item. The first item will be 001, the second 002, and so on. This number is used as a reference to refer to this item from the carton or pallet level.
amazon_product_identifier: Option<String>Amazon Standard Identification Number (ASIN) of an item.
vendor_product_identifier: Option<String>The vendor selected product identification of the item. Should be the same as was sent in the purchase order.
shipped_quantity: Box<ItemQuantity>item_details: Option<Box<ItemDetails>>Implementations